@@ -1,6 +1,6 @@
 /* Logging routines.
  *
- * IRC Services is copyright (c) 1996-2008 Andrew Church.
+ * IRC Services is copyright (c) 1996-2009 Andrew Church.
  *     E-mail: <achurch@achurch.org>
  * Parts written by Andrew Kempe and others.
  * This program is free but copyrighted software; see the file GPL.txt for
@@ -10,6 +10,9 @@
 #include "services.h"
 #include <netdb.h>  /* for hstrerror() */
 
+/* Pattern for generating logfile names */
+static char logfile_pattern[PATH_MAX+1];
+
 /* Currently open log file */
 static FILE *logfile;
 static char current_filename[PATH_MAX+1];
@@ -174,6 +177,17 @@ static void write_time(void)
 /*************************************************************************/
 /*************************************************************************/
 
+/* Set the filename pattern to use for generating the log filename. */
+
+void set_logfile(const char *pattern)
+{
+    if (pattern) {  /* Just to be safe */
+        strscpy(logfile_pattern, pattern, sizeof(logfile_pattern));
+    }
+}
+
+/*************************************************************************/
+
 /* Open the log file.  Return zero if the log file could not be opened,
  * else return nonzero (success).
  */
