@@ -1,6 +1,6 @@
 /* MemoServ functions.
  *
- * IRC Services is copyright (c) 1996-2008 Andrew Church.
+ * IRC Services is copyright (c) 1996-2009 Andrew Church.
  *     E-mail: <achurch@achurch.org>
  * Parts written by Andrew Kempe and others.
  * This program is free but copyrighted software; see the file GPL.txt for
@@ -273,6 +273,8 @@ static int memoserv(const char *source, const char *target, char *buf)
         }
         if (!valid_ngi(u) && stricmp(cmd, "HELP") != 0)
             notice_lang(s_MemoServ, u, NICK_NOT_REGISTERED_HELP, s_NickServ);
+        else if (!user_identified(u) && stricmp(cmd, "HELP") != 0)
+            notice_lang(s_MemoServ, u, NICK_IDENTIFY_REQUIRED, s_NickServ);
         else if (call_callback_2(cb_command, u, cmd) <= 0)
             run_cmd(s_MemoServ, u, THIS_MODULE, cmd);
     }
@@ -549,6 +551,7 @@ static int send_memo(const User *source, const char *target, const char *text,
             /* Deliver the memo ourselves */
             ARRAY_EXTEND(mi->memos);
             m = &mi->memos[mi->memos_count-1];
+            memset(m->sender, 0, NICKMAX);  // Avoid leaking random data
             strbcpy(m->sender, source->nick);
             if (mi->memos_count > 1) {
                 m->number = m[-1].number + 1;
@@ -879,9 +882,6 @@ static void do_send(User *u)
     } else if (!target || !text) {
         syntax_error(s_MemoServ, u, "SEND", MEMO_SEND_SYNTAX);
 
-    } else if (!user_identified(u)) {
-        notice_lang(s_MemoServ, u, NICK_IDENTIFY_REQUIRED, s_NickServ);
-
     } else if (MSSendDelay > 0
                && (u && u->lastmemosend+MSSendDelay > now)
                && !is_services_admin(u)) {
@@ -1316,13 +1316,17 @@ static void do_info(User *u)
         }
         mi = &ngi->memos;
         is_hardmax = ngi->flags & NF_MEMO_HARDMAX ? 1 : 0;
-    } else { /* !name or !servadmin*/
+    } else { /* !name or !servadmin */
         if (!user_identified(u)) {
             notice_lang(s_MemoServ, u, NICK_IDENTIFY_REQUIRED, s_NickServ);
             return;
         }
         ni = u->ni;
+        if (ni)
+            ni->usecount++;
         ngi = u->ngi;
+        if (ngi)
+            ngi->usecount++;
         mi = &u->ngi->memos;
     }
     max = REALMAX(mi->memomax);
