@@ -1,6 +1,6 @@
 /* Routines to export Services databases in XML format.
  *
- * IRC Services is copyright (c) 1996-2008 Andrew Church.
+ * IRC Services is copyright (c) 1996-2009 Andrew Church.
  *     E-mail: <achurch@achurch.org>
  * Parts written by Andrew Kempe and others.
  * This program is free but copyrighted software; see the file GPL.txt for
@@ -307,10 +307,12 @@ static int export_channel_db(xml_writefunc_t writefunc, void *data)
         writefunc(data, "\t\t</levels>\n");
         writefunc(data, "\t\t<chanaccesslist count='%d'>\n", ci->access_count);
         ARRAY_FOREACH (i, ci->access) {
-            writefunc(data, "\t\t\t<chanaccess>\n");
-            XML_PUT_ULONG ("\t\t\t\t", ci->access[i], nickgroup);
-            XML_PUT_LONG  ("\t\t\t\t", ci->access[i], level);
-            writefunc(data, "\t\t\t</chanaccess>\n");
+            if (ci->access[i].nickgroup) {  // Skip empty entries
+                writefunc(data, "\t\t\t<chanaccess>\n");
+                XML_PUT_ULONG ("\t\t\t\t", ci->access[i], nickgroup);
+                XML_PUT_LONG  ("\t\t\t\t", ci->access[i], level);
+                writefunc(data, "\t\t\t</chanaccess>\n");
+            }
         }
         writefunc(data, "\t\t</chanaccesslist>\n");
         writefunc(data, "\t\t<akicklist count='%d'>\n", ci->akick_count);
