@@ -1,6 +1,6 @@
 /* Main NickServ module.
  *
- * IRC Services is copyright (c) 1996-2008 Andrew Church.
+ * IRC Services is copyright (c) 1996-2009 Andrew Church.
  *     E-mail: <achurch@achurch.org>
  * Parts written by Andrew Kempe and others.
  * This program is free but copyrighted software; see the file GPL.txt for
@@ -346,6 +346,7 @@ static void clean_dbtables(void)
 static void db_get_mainnick(const void *record, void **value_ret)
 {
     NickGroupInfo *ngi = (NickGroupInfo *)record;
+    memset((char *)value_ret, 0, NICKMAX);
     strscpy((char *)value_ret, ngi->nicks[ngi->mainnick], NICKMAX);
 }
 
@@ -1098,8 +1099,11 @@ static void do_identify(User *u)
     } else if (call_callback_2(cb_id_check, u, pass) <= 0) {
         int old_authstat = ni->authstat;
         set_identified(u);
-        module_log("%s!%s@%s identified for nick %s",
-                   u->nick, u->username, u->host, u->nick);
+        if (!(old_authstat & NA_IDENTIFIED)) {
+            /* Only log if the user wasn't previously identified */
+            module_log("%s!%s@%s identified for nick %s",
+                       u->nick, u->username, u->host, u->nick);
+        }
         notice_lang(s_NickServ, u, NICK_IDENTIFY_SUCCEEDED);
         call_callback_2(cb_identified, u, old_authstat);
     }
@@ -1310,7 +1314,7 @@ static void do_dropemail_confirm(User *u)
     notice_lang(s_NickServ, u, NICK_DROPEMAIL_CONFIRM_DROPPED);
     if (WallAdminPrivs) {
         wallops(s_NickServ, "\2%s\2 used DROPEMAIL for \2%s\2 (%d nicks"
-                " dropped", u->nick, mask, dropemail_buffer[i].count);
+                " dropped)", u->nick, mask, dropemail_buffer[i].count);
     }
 }
 
