@@ -2,7 +2,7 @@
  * Based on code copyright (c) 1999-2000 Andrew Kempe (TheShadow)
  *     E-mail: <andrewk@isdial.net>
  *
- * IRC Services is copyright (c) 1996-2008 Andrew Church.
+ * IRC Services is copyright (c) 1996-2009 Andrew Church.
  *     E-mail: <achurch@achurch.org>
  * Parts written by Andrew Kempe and others.
  * This program is free but copyrighted software; see the file GPL.txt for
@@ -303,6 +303,7 @@ static void del_session(const char *host)
 
 static void do_exception_add(User *u);
 static void do_exception_del(User *u);
+static void do_exception_clear(User *u);
 static void do_exception_move(User *u);
 static void do_exception_list(User *u, int is_view);
 static void do_exception_check(User *u);
@@ -322,6 +323,8 @@ static void do_exception(User *u)
         do_exception_add(u);
     } else if (stricmp(cmd, "DEL") == 0) {
         do_exception_del(u);
+    } else if (stricmp(cmd, "CLEAR") == 0) {
+        do_exception_clear(u);
     } else if (stricmp(cmd, "MOVE") == 0) {
         do_exception_move(u);
     } else if (stricmp(cmd, "LIST") == 0 || stricmp(cmd, "VIEW") == 0) {
@@ -495,6 +498,28 @@ static int exception_del_callback(int num, va_list args)
 
 /*************************************************************************/
 
+static void do_exception_clear(User *u)
+{
+    char *mask;
+    MaskData *except;
+
+    mask = strtok(NULL, " ");
+    if (!mask || stricmp(mask,"ALL") != 0) {
+        syntax_error(s_OperServ, u, "EXCEPTION", OPER_EXCEPTION_CLEAR_SYNTAX);
+        return;
+    }
+    for (except = first_maskdata(MD_EXCEPTION); except;
+         except = next_maskdata(MD_EXCEPTION)
+    ) {
+        del_maskdata(MD_EXCEPTION, except);
+    }
+    notice_lang(s_OperServ, u, OPER_EXCEPTION_CLEARED);
+    if (readonly)
+        notice_lang(s_OperServ, u, READ_ONLY_MODE);
+}
+
+/*************************************************************************/
+
 static void do_exception_move(User *u)
 {
     MaskData *except;
